@@ -1,6 +1,6 @@
 import os
 
-version = '0.0.16'
+version = '0.0.17'
 
 # 开发
 login_base_url_develop = 'http://develop.flowhub.com.cn:8080'
@@ -8,13 +8,13 @@ cloud_base_url_develop = 'http://develop.flowhub.com.cn:8081'
 docker_registry_develop = 'develop.flowhub.com.cn:5000'
 
 # 测试
-login_base_url_stage = 'http://stage.flowhub.com.cn:8080'
-cloud_base_url_stage = 'http://stage.flowhub.com.cn:8081'
+login_base_url_stage = 'https://stage.flowhub.com.cn/backend'
+cloud_base_url_stage = 'https://stage.flowhub.com.cn/cloud'
 docker_registry_stage = 'stage.flowhub.com.cn:5000'
 
 # 生产
-login_base_url_master = 'http://www.flowhub.com.cn:8080'
-cloud_base_url_master = 'http://www.flowhub.com.cn:8081'
+login_base_url_master = 'https://www.flowhub.com.cn/backend'
+cloud_base_url_master = 'https://www.flowhub.com.cn/cloud'
 docker_registry_master = 'tool.flowhub.com.cn:5000'
 
 cli_dir = '.cli'
