@@ -1,32 +1,34 @@
 import os, json
 
-template = {
+template = """{
+    "id": "",
     "name": "",
     "desc": "",
-    "cmd": "",
-    "id": "",
+    "cmd": '''''',
     "imageName": "",
     "inputs": [
         {
-            "key": "",
             "label": "",
-            "name": "*"
+            "key": "",
+            "name": ""
         }
     ],
     "outputs": [
         {
-            "key": "",
             "label": "",
+            "key": "",
             "name": ""
         }
     ]
-}
+}"""
 
 
 def initTool(name):
-    template['name'] = name.strip()
+
+    str = template.replace("\"name\": \"\",", "\"name\": \"" + name.strip() + "\",");
     cur_path = os.getcwd()
-    with open(cur_path + '/tool.json', 'w') as f:
-        f.write(json.dumps(template, indent=4, ensure_ascii=False))
+    print(template)
+    with open(cur_path + '/tool.py', 'w', encoding="utf-8") as f:
+        f.write(str)
     os.mkdir(os.getcwd() + '/input')
     os.mkdir(os.getcwd() + '/output')
